@@ -245,7 +245,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 			vpc=self.vpc
 		)
 		listener = load_balancer.add_listener('substrate-elb-listener', port=443)
-		listener.add_targets('substrate-ec2-targets', targets=self.nodes)
+		listener.add_targets('substrate-ec2-targets', *self.nodes)
 
 	def provision_fs(self):
 		efs_sg = ec2.SecurityGroup(self, 'substrate-efs-sg', vpc=self.vpc)
